﻿#define DEBUG_AGENT

using System.Diagnostics;
using System.Windows;
using Microsoft.Phone.Scheduler;
using Microsoft.Phone.Shell;
using System;
using System.Windows.Media.Imaging;
using SharedClassLibrary;
using System.IO.IsolatedStorage;

namespace ScheduledTaskAgent1
{
    public class ScheduledAgent : ScheduledTaskAgent
    {
        /// <remarks>
        /// ScheduledAgent constructor, initializes the UnhandledException handler
        /// </remarks>
        static ScheduledAgent()
        {
            // Subscribe to the managed exception handler
            Deployment.Current.Dispatcher.BeginInvoke(delegate
            {
                Application.Current.UnhandledException += UnhandledException;
            });
        }

        /// Code to execute on Unhandled Exceptions
        private static void UnhandledException(object sender, ApplicationUnhandledExceptionEventArgs e)
        {
            if (Debugger.IsAttached)
            {
                // An unhandled exception has occurred; break into the debugger
                Debugger.Break();
            }
        }

        /// <summary>
        /// Agent that runs a scheduled task
        /// </summary>
        /// <param name="task">
        /// The invoked task
        /// </param>
        /// <remarks>
        /// This method is called when a periodic or resource intensive task is invoked
        /// </remarks>
        protected override void OnInvoke(ScheduledTask task)
        {
            //TODO: Add code to perform your task in background

            // Launch a toast to show that the agent is running.
            // The toast will not be shown if the foreground application is running.
            ShellToast toast = new ShellToast();
            toast.Title = "SaveImage";
            toast.Content = "Save Image from ScheduledAgent";
            toast.Show();

            System.Windows.Deployment.Current.Dispatcher.BeginInvoke(delegate()
                {
                    SaveImage();
                });

            // Call NotifyComplete to let the system know the agent is done working.
            NotifyComplete();
        }

        private void SaveImage()
        {
            ChartUserControl chartUserControl = new ChartUserControl();

            chartUserControl.OnApplyTemplate();
            chartUserControl.UpdateLayout();
            chartUserControl.Measure(new Size(400, 400));
            chartUserControl.UpdateLayout();
            chartUserControl.Arrange(new Rect(0, 0, 400, 400));

            WriteableBitmap wbmp = new WriteableBitmap(400, 400);
            wbmp.Render(chartUserControl, null);
            wbmp.Invalidate();

            using (IsolatedStorageFile isf = IsolatedStorageFile.GetUserStoreForApplication())
            {
                using (IsolatedStorageFileStream imageStream = new IsolatedStorageFileStream("img2.jpg", System.IO.FileMode.Create, isf))
                {
                    wbmp.SaveJpeg(imageStream, wbmp.PixelWidth, wbmp.PixelHeight, 0, 100);
                }
            }
        }
    }
}