﻿#define DEBUG_AGENT

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using WritableBitmapDemo.Resources;
using System.Windows.Media.Imaging;
using System.IO.IsolatedStorage;
using Microsoft.Phone.Scheduler;
using SharedClassLibrary;
using System.IO;

namespace WritableBitmapDemo
{
    public partial class MainPage : PhoneApplicationPage
    {
        PeriodicTask periodicTask;
        string periodicTaskName = "PeriodicAgent";

        // Constructor
        public MainPage()
        {
            InitializeComponent();

            // Sample code to localize the ApplicationBar
            //BuildLocalizedApplicationBar();

            StartPeriodicAgent();

            CreateChartUserControl();
        }

        private void CreateChartUserControl()
        {
            ChartUserControl chartUserControl = new ChartUserControl();
            ChartUserControlPlaceholder.Children.Add(chartUserControl);
        }

        private void StartPeriodicAgent()
        {
            // Obtain a reference to the period task, if one exists
            periodicTask = ScheduledActionService.Find(periodicTaskName) as PeriodicTask;

            // If the task already exists and background agents are enabled for the
            // application, you must remove the task and then add it again to update 
            // the schedule
            if (periodicTask != null)
            {
                RemoveAgent(periodicTaskName);
            }

            periodicTask = new PeriodicTask(periodicTaskName);

            // The description is required for periodic agents. This is the string that the user
            // will see in the background services Settings page on the device.
            periodicTask.Description = "This demonstrates a periodic task.";

            // Place the call to Add in a try block in case the user has disabled agents.
            try
            {
                ScheduledActionService.Add(periodicTask);
                // If debugging is enabled, use LaunchForTest to launch the agent in one minute.
#if(DEBUG_AGENT)
                ScheduledActionService.LaunchForTest(periodicTaskName, TimeSpan.FromSeconds(60));
#endif
            }
            catch (InvalidOperationException exception)
            {
                if (exception.Message.Contains("BNS Error: The action is disabled"))
                {
                    //MessageBox.Show("Background agents for this application have been disabled by the user.");
                }

                if (exception.Message.Contains("BNS Error: The maximum number of ScheduledActions of this type have already been added."))
                {
                    // No user action required. The system prompts the user when the hard limit of periodic tasks has been reached.

                }
            }
            catch (SchedulerServiceException)
            {
                // No user action required.
            }
        }

        private void RemoveAgent(string name)
        {
            try
            {
                ScheduledActionService.Remove(name);
            }
            catch (Exception)
            {
            }
        }

        // Sample code for building a localized ApplicationBar
        //private void BuildLocalizedApplicationBar()
        //{
        //    // Set the page's ApplicationBar to a new instance of ApplicationBar.
        //    ApplicationBar = new ApplicationBar();

        //    // Create a new button and set the text value to the localized string from AppResources.
        //    ApplicationBarIconButton appBarButton = new ApplicationBarIconButton(new Uri("/Assets/AppBar/appbar.add.rest.png", UriKind.Relative));
        //    appBarButton.Text = AppResources.AppBarButtonText;
        //    ApplicationBar.Buttons.Add(appBarButton);

        //    // Create a new menu item with the localized string from AppResources.
        //    ApplicationBarMenuItem appBarMenuItem = new ApplicationBarMenuItem(AppResources.AppBarMenuItemText);
        //    ApplicationBar.MenuItems.Add(appBarMenuItem);
        //}
        private void But_OnClick(object sender, RoutedEventArgs e)
        {
            SaveImage();

            ShowImageFromScheduledTaskAgent();
        }

        private void SaveImage()
        {
            WriteableBitmap wbmp = new WriteableBitmap(400, 400);
            wbmp.Render(ChartUserControlPlaceholder.Children.FirstOrDefault(), null);
            wbmp.Invalidate();
            BitmapImage bmp = null;
            using (IsolatedStorageFile isf = IsolatedStorageFile.GetUserStoreForApplication())
            {
                using (IsolatedStorageFileStream imageStream = new IsolatedStorageFileStream("img1.jpg", System.IO.FileMode.Create, isf))
                {
                    wbmp.SaveJpeg(imageStream, wbmp.PixelWidth, wbmp.PixelHeight, 0, 100);
                    bmp = new BitmapImage();
                    bmp.SetSource(imageStream);
                }
            }
            img1.Source = bmp;
        }

        private void ShowImageFromScheduledTaskAgent()
        {
            BitmapImage bmp = null;
            try
            {
                using (IsolatedStorageFile isf = IsolatedStorageFile.GetUserStoreForApplication())
                {
                    using (IsolatedStorageFileStream imageStream = isf.OpenFile("img2.jpg", System.IO.FileMode.Open, FileAccess.Read))
                    {
                        bmp = new BitmapImage();
                        bmp.SetSource(imageStream);
                    }
                }
                img2.Source = bmp;
            }
            catch (Exception ex)
            {
                // handle the exception
            }
        }
    }

/*    public class ViewModel
    {
        readonly Random rnd=new Random();
        public ViewModel()
        {
            DataModels =new ObservableCollection<Model>();
            for(int i=1;i<5;i++)
                DataModels.Add(new Model(){Xvalue=i,Yvalue=rnd.Next(10,50)});
        }
        public ObservableCollection<Model> DataModels { get; set; } 
    }

    public class Model
    {
        public double Xvalue { get; set; }
        public double Yvalue { get; set; }
    }*/
}